# Contribution

## Bug Reports & Feature Requests

* Do not open up a GitHub issue if the bug is a security vulnerability, and instead to please contact the owner of the repository directly.

* **Ensure the bug was not already reported** by searching on GitHub under [Issues](https://github.com/oribarilan/oplog/issues).

* If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/oribarilan/oplog/issues/new). Be sure to include a **title and clear description**, and as much relevant information as possible. Issues with **minimal code samples (repro)** or a **failing executable test case** demonstrating the expected behavior that is not occurring - will be prioritized.

## Documentation

Our documentation uses [MkDocs](https://www.mkdocs.org/) and the [Material for MkDocs](https://squidfunk.github.io/mkdocs-material/) theme.
Use the following commands to run a local documentation server for documentation contribution:

```bash
mkdocs serve
```

Make sure you open the documentation in your browser as incognito/private mode.

## Code

### Fix a Bug

* Open a new GitHub pull request with the fix.

* Ensure the PR description clearly describes the problem and solution. Include the relevant issue number.

* Make sure you follow our coding conventions. 

## Add a Feature

* oplog grows by tackling needs and pain of developers. First, report the issue (even if not a bug) as mentioned above.

* Follow the same steps as for fixing a bug.

💚 Thanks for supporting oplog! ⧓